<?php

/**
 * @file
 * Theme functions for the page_theme module.
 */


/**
 * Returns HTML for the page_theme administration overview form.
 *
 * @param $variables
 *   An associative array containing:
 *   - form: A render element representing the form.
 *
 * @ingroup themeable
 */
function theme_page_theme_admin_overview($variables) {

  $form = $variables['form'];

  $rows = array();

  foreach (element_children($form['rules']) as $rule) {

    $form['rules'][$rule]['weight']['#attributes']['class'] = array('page-theme-order-weight');

    $row = array();
    $row[] = drupal_render($form['rules'][$rule]['name']);
    $row[] = drupal_render($form['rules'][$rule]['theme']);
    $row[] = drupal_render($form['rules'][$rule]['pages']);
    $row[] = drupal_render($form['rules'][$rule]['roles']);
    $row[] = drupal_render($form['rules'][$rule]['status']);
    $row[] = drupal_render($form['rules'][$rule]['weight']);
    $row[] = drupal_render($form['rules'][$rule]['configure']);
    $row[] = drupal_render($form['rules'][$rule]['delete']);

    $rows[] = array('data' => $row, 'class' => array('draggable'));
  }

  $header = array();
  $header[] = t('Name');
  $header[] = t('Theme');
  $header[] = t('Pages');
  $header[] = t('Roles');
  $header[] = t('Enabled');
  $header[] = t('Weight');
  $header[] = array('data' => t('Operations'), 'colspan' => '2');

  $output = theme('table', array(
    'header' => $header,
    'rows' => $rows,
    'attributes' => array('id' => 'page-theme-order'),
    'empty' => drupal_placeholder(t('No rules defined.')),
  ));
  $output .= drupal_render_children($form);

  drupal_add_tabledrag('page-theme-order', 'order', 'sibling', 'page-theme-order-weight');

  return $output;
}
